#[non_exhaustive]pub enum PayloadState {
Cleartext,
Encrypted {
scheme: &'static str,
reason: &'static str,
},
Undecoded {
error: String,
},
}Expand description
The recoverability state of a record’s content.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Cleartext
The content is in cleartext (metadata records, or a message whose body was extractable).
Encrypted
The content is client-side encrypted and its key is not recoverable from this artifact.
Fields
Undecoded
The value could not be decoded from its Blink/V8 blob upstream.