#[non_exhaustive]pub enum WireRecordKind {
Conversation,
Event,
User,
Client,
Unknown,
}Expand description
Which Wire object store a record came from — the Dexie store name mapped to a forensic role.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Conversation
conversations — conversation/group metadata.
Event
events — message and system events (the chat log).
User
users — the contact roster.
Client
clients — registered devices/clients.
Unknown
An object store this reader does not map to a Wire role.
Implementations
Sourceimpl WireRecordKind
impl WireRecordKind
Sourcepub fn from_store_name(name: &str) -> WireRecordKind
pub fn from_store_name(name: &str) -> WireRecordKind
Map a Dexie object-store name to its Wire role.